pub struct Envs {
pub package_consumer_count: i32,
pub min_allocated_memory: usize,
pub garbage_collection: bool,
pub garbage_collection_interval: u64,
pub default_package_repository_url: String,
pub main: String,
}Fields
package_consumer_count: i32Number of package consumers
This is the number of threads that will be used to process packages. Environment variable: PHLOW_PACKAGE_CONSUMERS_COUNT Default: 10
min_allocated_memory: usizeMinimum allocated memory in MB
This is the minimum amount of memory that will be allocated to the process. Environment variable: PHLOW_MIN_ALLOCATED_MEMORY_MB Default: 10
garbage_collection: boolEnable garbage collection
This will enable or disable garbage collection. Environment variable: PHLOW_GARBAGE_COLLECTION_ENABLED Default: true
garbage_collection_interval: u64Garbage collection interval in seconds
This is the interval at which garbage collection will be performed. Environment variable: PHLOW_GARBAGE_COLLECTION_INTERVAL_SECONDS Default: 60
default_package_repository_url: StringDefault package repository URL
This is the URL of the default package repository that will be used to fetch packages. Environment variable: PHLOW_DEFAULT_PACKAGE_REPOSITORY_URL Default: https://packages.phlow.dev/packages
main: StringDefault phlow file main
This is the default main file that will be used to run the phlow file. Environment variable: PHLOW_MAIN Default: None
Implementations